@@ -163,6 +163,13 @@ def snapshot(buildout):
             snap.append(os.path.join(folder, dir_))
     return snap
 
+def _python():
+    """returns python bin"""
+    python = join('bin', 'python')
+    if not os.path.exists(os.path.realpath(python)):
+        return join('bin', 'python2.4')
+    return python
+
 def deploy_release(path=None, target=None, archiving=None):
     """deploy a release in-place"""
     print 'Checking python version ...'
@@ -185,12 +192,13 @@ def deploy_release(path=None, target=None, archiving=None):
     if not os.path.isdir(target):
         os.mkdir(target)
 
-    # changes all paths
-    os.chdir(target)
+    root = os.path.realpath(target)
+    os.chdir(root)
 
+    # changes all paths
     if not os.path.isfile(path) and not os.path.isdir(path):
         # let's get the buildout
-        base.system('svn co %s .' % url)
+        print base.system('svn co %s .' % url)
     else:
         target = url
 
@@ -207,28 +215,14 @@ def deploy_release(path=None, target=None, archiving=None):
         sys.argv = old
 
     # now we can run bootstrap.py
-    python = os.path.join('bin', 'python')
-    base.system('%s bootstrap.py' % python)
+    python = _python()
+
+    print base.system('%s bootstrap.py' % python)
 
     # then bin/buildout -v
     binary = join('bin', 'buildout')
     buildout = 'buildout.cfg'
 
-    # see if a develop remains
-    try:
-        develop = get_option(filename, 'buildout', 'develop')
-    except ConfigParser.NoOptionError:
-        # ok we are safe
-        pass
-    else:
-        # we need to develop them
-        develops = ['    %s' % line.strip()
-                    for line in develop.split('\n')
-                    if line.strip() != '']
-        msg = '\nYou need to make releases of theses packages:\n%s'
-        msg = msg % '\n'.join(develops)
-        raise base.ReleaseError(msg)
-
     # see if download-cache was present
     try:
         cache = get_option(filename, 'buildout', 'download-cache')
@@ -237,13 +231,15 @@ def deploy_release(path=None, target=None, archiving=None):
                                  "' in the [buildout] section"))
 
     print 'Checking binary.'
-    if not base.check_command('%s -v' % binary):
+    buildout_cmd = '%s -c %s -v' % (binary, filename)
+    print 'Calling %s' % buildout_cmd
+    if not base.check_command(buildout_cmd):
         raise base.ReleaseError('Something went wrong in deployement')
     print '%s ok.' % binary
 
     # snapshot process: lists all files that where created in
     # downloads and eggs to commit them in .snapshot
-    snapshot_file = '.snapshot'
+    snapshot_file = join(root, '.snapshot')
     f = open(snapshot_file, 'w')
     try:
         f.write('\n'.join(snapshot('.')))
