@@ -18,10 +18,11 @@
 """
 import unittest
 import os
+import shutil
 
 from zc.buildout.testing import rmdir
 
-from iw.releaser.project import archive_contents
+from iw.releaser.project import archive_contents, _python
 from iw.releaser import testing
 from iw.releaser import base
 
@@ -77,6 +78,28 @@ class ProjectTest(unittest.TestCase):
 
         os.remove(tarfile_)
 
+    def test_python(self):
+        # virtualenv generates python either python2.4
+        test_bin = os.path.join(os.path.dirname(__file__), 
+                                'test_bin')
+        os.mkdir(test_bin)
+        os.chdir(test_bin)
+        try:
+            os.mkdir(os.path.join(test_bin, 'bin'))
+            f = open(os.path.join(test_bin, 'bin', 'python'), 'w')
+            f.write('#')
+            f.close()
+            python = _python()    
+            self.assertEquals(python, 'bin/python')
+            os.remove(python)
+            f = open(os.path.join(test_bin, 'bin', 'python2.4'), 'w')
+            f.write('#')
+            f.close()
+            python = _python()    
+            self.assertEquals(python, 'bin/python2.4')
+        finally:
+            shutil.rmtree(test_bin)
+
 def test_suite():
     """returns the test suite"""
     return unittest.makeSuite(ProjectTest)
